import request from '@/utils/request'
import Qs from 'qs'

/**
 * 1.查询角色列表
 * 2.查询角色详细
 * 3.新增角色
 * 4.修改角色
 * 5.角色数据权限
 * 6.角色状态修改
 * 7.删除角色
 * 8.导出角色
 * */

// 查询角色列表
export function listRole(query) {
  return request({
    url: '/system/role/list',
    method: 'get',
    params: query
  })
}

// 查询角色详细
export function getRole(businessId) {
  return request({
    url: '/system/role/detail/' + businessId,
    method: 'get'
  })
}

// 新增角色
export function addRole(data) {
  data = Qs.stringify(data)
  return request({
    url: '/system/role/add',
    method: 'post',
    data: data,
    headers: {}
  })
}

// 修改角色
export function updateRole(data) {
  const businessId = data.businessId
  data = Qs.stringify(data)
  return request({
    url: '/system/role/update/' + businessId,
    method: 'put',
    data,
    headers: {}
  })
}

// 角色数据权限
export function dataScope(data) {
  data = Qs.stringify(data)
  return request({
    url: '/system/role/dataScope',
    method: 'put',
    data,
    headers: {}
  })
}

// 角色状态修改
export function changeRoleStatus(businessId, flag) {
  const data = {
    businessId,
    flag
  }
  return request({
    url: '/system/role/changeStatus',
    method: 'put',
    params: data
  })
}

// 删除角色
export function delRole(roleId) {
  return request({
    url: '/system/role/deleteLogical/' + roleId,
    method: 'delete'
  })
}

// 导出角色
export function exportRole(query) {
  return request({
    url: '/system/role/export',
    method: 'get',
    params: query,
    responseType: 'blob'
  })
}
